SystemOrganization addCategory: #ConfigurationOfXMLParserHTML!

Object subclass: #ConfigurationOfXMLParserHTML
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfXMLParserHTML'!

!ConfigurationOfXMLParserHTML commentStamp: 'monty 4/22/2017 16:19' prior: 0!
Loads the XMLParserHTML library and related packages:
	(ConfigurationOfXMLParserHTML project version: #stable) load: #('default')

The loadable groups are:
	default - XMLParserHTML, XMLParser, and XMLWriter with tests.
	Core - XMLParserHTML and XMLParser without XMLWriter  or tests.
	CoreWithWriting - XMLParserHTML, XMLParser, and XMLWriter without tests.!

!ConfigurationOfXMLParserHTML class methodsFor: 'development support' stamp: 'monty 10/9/2014 16:38'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfXMLParserHTML class methodsFor: 'private' stamp: 'monty 10/9/2014 16:38'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfXMLParserHTML class methodsFor: 'catalog' stamp: 'monty 3/24/2015 21:03'!
catalogDescription

	^ 'XMLParserHTML provides SAX and DOM parsers for HTML that convert possibly malformed HTML into well-formed XML.'
! !

!ConfigurationOfXMLParserHTML class methodsFor: 'catalog' stamp: 'monty 3/24/2015 21:07'!
catalogKeyClassesAndExample

	^ 'The main classes are ==SAXHTMLHandler== and ==XMLHTMLParser== (DOM).
	
	Here is an example:
[[[ 
	"get all links from the Pharo homepage"
	((XMLHTMLParser parseURL: ''http://pharo.org'') allElementsNamed: ''a'')
		collect: [:each | each attributeAt: ''href''].
]]]'! !

!ConfigurationOfXMLParserHTML class methodsFor: 'catalog' stamp: 'monty 4/7/2015 00:40'!
catalogKeywords

	^ #( HTML SAX DOM parser web markup document)! !

!ConfigurationOfXMLParserHTML class methodsFor: 'catalog' stamp: 'monty 1/8/2016 13:26'!
catalogLicense
	^ 'The MIT License (MIT)

Copyright (c) 2016 PharoExtras Team.

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.'! !

!ConfigurationOfXMLParserHTML class methodsFor: 'private' stamp: 'monty 10/9/2014 16:38'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfXMLParserHTML class methodsFor: 'private' stamp: 'monty 10/9/2014 16:38'!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfXMLParserHTML class methodsFor: 'metacello tool support' stamp: 'monty 10/9/2014 16:38'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfXMLParserHTML class methodsFor: 'loading' stamp: 'monty 10/9/2014 16:38'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfXMLParserHTML class methodsFor: 'loading' stamp: 'monty 10/9/2014 16:38'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfXMLParserHTML class methodsFor: 'loading' stamp: 'monty 10/9/2014 16:38'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfXMLParserHTML class methodsFor: 'accessing' stamp: 'monty 10/9/2014 16:38'!
project

	^self new project! !

!ConfigurationOfXMLParserHTML class methodsFor: 'development support' stamp: 'monty 10/9/2014 16:38'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfXMLParserHTML methodsFor: 'baselines' stamp: 'monty 6/5/2017 16:59'!
baseline100: spec
	<version: '1.0.0-baseline'>
	spec
		for: #common
		do: [ 
			spec
				blessing: #baseline;
				description: 'XML-Parser-HTML baseline';
				"migrated from PharoExtras/XMLParser to PharoExtras/XMLParserHTML"
				repository: 'http://smalltalkhub.com/mc/PharoExtras/XMLParserHTML/main'.
			spec
				project: 'XMLParser'
				with: [ 
					spec
						className: 'ConfigurationOfXMLParser';
						versionString: #stable;
						loads: #('Core');
						repository: 'http://smalltalkhub.com/mc/PharoExtras/XMLParser/main' ].
			spec
				project: 'XMLParserCoreWithWriting'
				copyFrom: 'XMLParser'
				with: [ spec loads: #('CoreWithWriting') ].
			spec
				project: 'XMLParserTests'
				copyFrom: 'XMLParser'
				with: [ spec loads: #('Tests') ].
			spec package: 'XML-Parser-HTML-Core' with: [ spec requires: 'XMLParser' ].
			spec package: 'XML-Parser-HTML-Tests' with: [
				spec requires: #('XMLParserTests' 'XML-Parser-HTML-Core') ].
			spec
				group: 'default' with: #('CoreWithWriting' 'Tests');
				group: 'Core' with: #('XML-Parser-HTML-Core');
				group: 'CoreWithWriting' with: #('XMLParserCoreWithWriting' 'XML-Parser-HTML-Core');
				group: 'Tests' with: #('XML-Parser-HTML-Tests')].

	"load gemstone methods"
	spec
		for: #'gemstone'
		do: [
			spec
				package: 'XML-Parser-HTML-Core'
				with: [ spec includes: 'XML-Parser-HTML-GemstoneCompatibility' ].
			spec
				package: 'XML-Parser-HTML-GemstoneCompatibility'
				with: [ spec requires: 'XML-Parser-HTML-Core' ]. ].! !

!ConfigurationOfXMLParserHTML methodsFor: 'baselines' stamp: 'monty 12/3/2016 01:48'!
baseline114: spec
	<version: '1.1.4-baseline' imports: #('1.0.0-baseline')>
	spec
		for: #common
		do: [
			spec blessing: #baseline.
			spec project: 'XMLParser' with: #'release-2.5' ].
	spec
		for: #gemstone
		do: [ spec package: 'XML-Parser-HTML-GemstoneCompatibility' with: 'XML-Parser-HTML-GemstoneCompatibility-monty.1' ]! !

!ConfigurationOfXMLParserHTML methodsFor: 'baselines' stamp: 'monty 12/3/2016 01:48'!
baseline122: spec
	<version: '1.2.2-baseline' imports: #('1.0.0-baseline')>
	spec
		for: #common
		do: [
			spec blessing: #baseline.
			spec project: 'XMLParser' with: #'release-2.6.5' ].
	spec
		for: #gemstone
		do: [ spec package: 'XML-Parser-HTML-GemstoneCompatibility' with: 'XML-Parser-HTML-GemstoneCompatibility-monty.1' ]! !

!ConfigurationOfXMLParserHTML methodsFor: 'baselines' stamp: 'monty 12/3/2016 01:48'!
baseline124: spec
	<version: '1.2.4-baseline' imports: #('1.0.0-baseline')>
	spec
		for: #common
		do: [
			spec blessing: #baseline.
			spec project: 'XMLParser' with: #'release-2.6.8' ].
	spec
		for: #gemstone
		do: [ spec package: 'XML-Parser-HTML-GemstoneCompatibility' with: 'XML-Parser-HTML-GemstoneCompatibility-monty.1' ]! !

!ConfigurationOfXMLParserHTML methodsFor: 'baselines' stamp: 'monty 12/3/2016 01:47'!
baseline125: spec
	<version: '1.2.5-baseline' imports: #('1.0.0-baseline')>
	spec
		for: #common
		do: [
			spec blessing: #baseline.
			spec project: 'XMLParser' with: #'release-2.7.3' ].
	spec
		for: #gemstone
		do: [ spec package: 'XML-Parser-HTML-GemstoneCompatibility' with: 'XML-Parser-HTML-GemstoneCompatibility-monty.1' ]! !

!ConfigurationOfXMLParserHTML methodsFor: 'baselines' stamp: 'monty 12/3/2016 01:47'!
baseline126: spec
	<version: '1.2.6-baseline' imports: #('1.0.0-baseline')>
	spec
		for: #common
		do: [
			spec blessing: #baseline.
			spec project: 'XMLParser' with: #'release-2.7.4' ].
	spec
		for: #gemstone
		do: [ spec package: 'XML-Parser-HTML-GemstoneCompatibility' with: 'XML-Parser-HTML-GemstoneCompatibility-monty.1' ]! !

!ConfigurationOfXMLParserHTML methodsFor: 'baselines' stamp: 'monty 12/3/2016 01:47'!
baseline127: spec
	<version: '1.2.7-baseline' imports: #('1.0.0-baseline')>
	spec
		for: #common
		do: [
			spec blessing: #baseline.
			spec project: 'XMLParser' with: #'release-2.7.6' ].
	spec
		for: #gemstone
		do: [ spec package: 'XML-Parser-HTML-GemstoneCompatibility' with: 'XML-Parser-HTML-GemstoneCompatibility-monty.1' ]! !

!ConfigurationOfXMLParserHTML methodsFor: 'baselines' stamp: 'monty 12/3/2016 01:47'!
baseline128: spec
	<version: '1.2.8-baseline' imports: #('1.0.0-baseline')>
	spec
		for: #common
		do: [
			spec blessing: #baseline.
			spec project: 'XMLParser' with: #'release-2.8.1' ].
	spec
		for: #gemstone
		do: [ spec package: 'XML-Parser-HTML-GemstoneCompatibility' with: 'XML-Parser-HTML-GemstoneCompatibility-monty.1' ]! !

!ConfigurationOfXMLParserHTML methodsFor: 'baselines' stamp: 'monty 12/3/2016 01:48'!
baseline129: spec
	<version: '1.2.9-baseline' imports: #('1.0.0-baseline')>
	spec
		for: #common
		do: [
			spec blessing: #baseline.
			spec project: 'XMLParser' with: #'release-2.8.9' ].
	spec
		for: #gemstone
		do: [ spec package: 'XML-Parser-HTML-GemstoneCompatibility' with: 'XML-Parser-HTML-GemstoneCompatibility-monty.1' ]! !

!ConfigurationOfXMLParserHTML methodsFor: 'baselines' stamp: 'monty 12/3/2016 01:48'!
baseline130: spec
	<version: '1.3.0-baseline' imports: #('1.0.0-baseline')>
	spec
		for: #common
		do: [
			spec blessing: #baseline.
			spec project: 'XMLParser' with: #'release-2.9.2' ].
	spec
		for: #gemstone
		do: [ spec package: 'XML-Parser-HTML-GemstoneCompatibility' with: 'XML-Parser-HTML-GemstoneCompatibility-monty.1' ]! !

!ConfigurationOfXMLParserHTML methodsFor: 'baselines' stamp: 'monty 12/3/2016 01:48'!
baseline131: spec
	<version: '1.3.1-baseline' imports: #('1.0.0-baseline')>
	spec
		for: #common
		do: [
			spec blessing: #baseline.
			spec project: 'XMLParser' with: #'release-2.9.5' ].
	spec
		for: #gemstone
		do: [ spec package: 'XML-Parser-HTML-GemstoneCompatibility' with: 'XML-Parser-HTML-GemstoneCompatibility-monty.1' ]! !

!ConfigurationOfXMLParserHTML methodsFor: 'baselines' stamp: 'monty 2/26/2017 12:17'!
baseline132: spec
	<version: '1.3.2-baseline' imports: #('1.0.0-baseline')>
	spec
		for: #common
		do: [
			spec blessing: #baseline.
			spec project: 'XMLParser' with: #'release-3' ].
	spec
		for: #gemstone
		do: [ 
			spec package: 'XML-Parser-HTML-GemstoneCompatibility' with: 'XML-Parser-HTML-GemstoneCompatibility-monty.1'.

			"force initialization of lazy-initialized class and class isnt
			vars to avoid write conflicts on GS"
			spec postLoadDoIt: #initializeClassesForGSBaseline132. ]! !

!ConfigurationOfXMLParserHTML methodsFor: 'baselines' stamp: 'monty 4/13/2017 06:01'!
baseline134: spec
	<version: '1.3.4-baseline' imports: #('1.0.0-baseline')>
	spec
		for: #common
		do: [
			spec blessing: #baseline.
			spec project: 'XMLParser' with: #'release-3.0.6' ].
	spec
		for: #gemstone
		do: [ 
			spec package: 'XML-Parser-HTML-GemstoneCompatibility' with: 'XML-Parser-HTML-GemstoneCompatibility-monty.1'.

			"force initialization of lazy-initialized class and class isnt
			vars to avoid write conflicts on GS"
			spec postLoadDoIt: #initializeClassesForGSBaseline132. ]! !

!ConfigurationOfXMLParserHTML methodsFor: 'baselines' stamp: 'monty 5/20/2017 03:36'!
baseline136: spec
	<version: '1.3.6-baseline' imports: #('1.0.0-baseline')>
	spec
		for: #common
		do: [
			spec blessing: #baseline.
			spec project: 'XMLParser' with: #'release-3.1.7' ].
	spec
		for: #gemstone
		do: [ 
			spec package: 'XML-Parser-HTML-GemstoneCompatibility' with: 'XML-Parser-HTML-GemstoneCompatibility-monty.1'.

			"force initialization of lazy-initialized class and class isnt
			vars to avoid write conflicts on GS"
			spec postLoadDoIt: #initializeClassesForGSBaseline132. ]! !

!ConfigurationOfXMLParserHTML methodsFor: 'baselines' stamp: 'monty 8/31/2017 07:38'!
baseline138: spec
	<version: '1.3.8-baseline' imports: #('1.0.0-baseline')>
	spec
		for: #common
		do: [
			spec blessing: #baseline.
			spec project: 'XMLParser' with: #'release-3.1.9' ].
	spec
		for: #gemstone
		do: [ 
			spec package: 'XML-Parser-HTML-GemstoneCompatibility' with: 'XML-Parser-HTML-GemstoneCompatibility-monty.1'.

			"force initialization of lazy-initialized class and class isnt
			vars to avoid write conflicts on GS"
			spec postLoadDoIt: #initializeClassesForGSBaseline132. ]! !

!ConfigurationOfXMLParserHTML methodsFor: 'baselines' stamp: 'monty 10/17/2017 01:54'!
baseline139: spec
	<version: '1.3.9-baseline' imports: #('1.0.0-baseline')>
	spec
		for: #common
		do: [
			spec blessing: #baseline.
			spec project: 'XMLParser' with: #'release-3.2.2' ].
	spec
		for: #gemstone
		do: [ 
			spec package: 'XML-Parser-HTML-GemstoneCompatibility' with: 'XML-Parser-HTML-GemstoneCompatibility-monty.1'.

			"force initialization of lazy-initialized class and class isnt
			vars to avoid write conflicts on GS"
			spec postLoadDoIt: #initializeClassesForGSBaseline139. ]! !

!ConfigurationOfXMLParserHTML methodsFor: 'baselines' stamp: 'monty 1/23/2018 08:09'!
baseline141: spec
	<version: '1.4.1-baseline' imports: #('1.0.0-baseline')>
	spec
		for: #common
		do: [
			spec blessing: #baseline.
			spec project: 'XMLParser' with: #'release-3.2.9' ].
	spec
		for: #gemstone
		do: [ 
			spec package: 'XML-Parser-HTML-GemstoneCompatibility' with: 'XML-Parser-HTML-GemstoneCompatibility-monty.1'.

			"force initialization of lazy-initialized class and class isnt
			vars to avoid write conflicts on GS"
			spec postLoadDoIt: #initializeClassesForGSBaseline139. ]! !

!ConfigurationOfXMLParserHTML methodsFor: 'accessing' stamp: 'monty 10/9/2014 16:38'!
customProjectAttributes
	 "Edit to return a collection of any custom attributes e.g. for conditional loading: Array with: #'Condition1' with: #'Condition2.
	For more information see: http://code.google.com/p/metacello/wiki/CustomProjectAttrributes"

	^ #().! !

!ConfigurationOfXMLParserHTML methodsFor: 'symbolic versions' stamp: 'monty 1/23/2018 08:09'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: '1.4.1-baseline'.! !

!ConfigurationOfXMLParserHTML methodsFor: 'doits' stamp: 'monty 1/23/2018 16:19'!
initializeClassesForGSBaseline132
	"All lazily initialized class and class instance variables must be
	explicitly initialized on GS during installation to prevent write
	conflicts between Gems later on. 
	
	This can help identify classes that use lazy initialization:
		ConfigurationOfXMLParser findLazyInitializedClassStateInPackage:
			'XML-Parser-HTML'
	"

	"renamed"
	(XMLClassFinder classNamed: #XMLHTMLNonHTMLSectionContext) allSubclassesDo: [:each |
		each instance]! !

!ConfigurationOfXMLParserHTML methodsFor: 'doits' stamp: 'monty 1/23/2018 16:19'!
initializeClassesForGSBaseline139
	"All lazily initialized class and class instance variables must be
	explicitly initialized on GS during installation to prevent write
	conflicts between Gems later on. 
	
	This can help identify classes that use lazy initialization:
		ConfigurationOfXMLParser findLazyInitializedClassStateInPackage:
			'XML-Parser-HTML'
	"

	XMLHTMLNonHTMLSectionState allSubclassesDo: [:each |
		each instance]! !

!ConfigurationOfXMLParserHTML methodsFor: 'accessing' stamp: 'monty 10/9/2014 16:38'!
project

	^ project ifNil: [ 
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		project := MetacelloMCProject new projectAttributes: self customProjectAttributes. 
		(Smalltalk at: #MetacelloVersionConstructor) on: self project: project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfXMLParserHTML methodsFor: 'symbolic versions' stamp: 'monty 1/23/2018 08:09'!
stable: spec
	<symbolicVersion: #'stable'>

	spec for: #'common' version: '1.4.1'.
! !

!ConfigurationOfXMLParserHTML methodsFor: 'versions' stamp: 'monty 10/14/2014 23:28'!
version100: spec 
        <version: '1.0.0' imports: #('1.0.0-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser-HTML-Core' with: 'XML-Parser-HTML-Core-monty.2'.
			spec package: 'XML-Parser-HTML-Tests' with: 'XML-Parser-HTML-Tests-monty.1'.
                ].! !

!ConfigurationOfXMLParserHTML methodsFor: 'versions' stamp: 'monty 10/26/2014 14:25'!
version101: spec 
        <version: '1.0.1' imports: #('1.0.0-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser-HTML-Core' with: 'XML-Parser-HTML-Core-monty.4'.
			spec package: 'XML-Parser-HTML-Tests' with: 'XML-Parser-HTML-Tests-monty.2'.
                ].! !

!ConfigurationOfXMLParserHTML methodsFor: 'versions' stamp: 'monty 10/27/2014 14:53'!
version102: spec 
        <version: '1.0.2' imports: #('1.0.0-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser-HTML-Core' with: 'XML-Parser-HTML-Core-monty.6'.
			spec package: 'XML-Parser-HTML-Tests' with: 'XML-Parser-HTML-Tests-monty.2'.
                ].! !

!ConfigurationOfXMLParserHTML methodsFor: 'versions' stamp: 'monty 11/7/2014 20:32'!
version103: spec 
        <version: '1.0.3' imports: #('1.0.0-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser-HTML-Core' with: 'XML-Parser-HTML-Core-monty.9'.
			spec package: 'XML-Parser-HTML-Tests' with: 'XML-Parser-HTML-Tests-monty.3'.
                ].! !

!ConfigurationOfXMLParserHTML methodsFor: 'versions' stamp: 'monty 11/19/2014 06:40'!
version104: spec 
        <version: '1.0.4' imports: #('1.0.0-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser-HTML-Core' with: 'XML-Parser-HTML-Core-monty.12'.
			spec package: 'XML-Parser-HTML-Tests' with: 'XML-Parser-HTML-Tests-monty.4'.
                ].! !

!ConfigurationOfXMLParserHTML methodsFor: 'versions' stamp: 'monty 11/28/2014 06:58'!
version105: spec 
        <version: '1.0.5' imports: #('1.0.0-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser-HTML-Core' with: 'XML-Parser-HTML-Core-monty.13'.
			spec package: 'XML-Parser-HTML-Tests' with: 'XML-Parser-HTML-Tests-monty.4'.
                ].! !

!ConfigurationOfXMLParserHTML methodsFor: 'versions' stamp: 'monty 11/29/2014 01:36'!
version106: spec 
        <version: '1.0.6' imports: #('1.0.0-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser-HTML-Core' with: 'XML-Parser-HTML-Core-monty.14'.
			spec package: 'XML-Parser-HTML-Tests' with: 'XML-Parser-HTML-Tests-monty.4'.
                ].! !

!ConfigurationOfXMLParserHTML methodsFor: 'versions' stamp: 'monty 12/12/2014 08:53'!
version107: spec 
        <version: '1.0.7' imports: #('1.0.0-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser-HTML-Core' with: 'XML-Parser-HTML-Core-monty.15'.
			spec package: 'XML-Parser-HTML-Tests' with: 'XML-Parser-HTML-Tests-monty.5'.
                ].! !

!ConfigurationOfXMLParserHTML methodsFor: 'versions' stamp: 'monty 12/14/2014 21:56'!
version108: spec 
        <version: '1.0.8' imports: #('1.0.0-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser-HTML-Core' with: 'XML-Parser-HTML-Core-monty.16'.
			spec package: 'XML-Parser-HTML-Tests' with: 'XML-Parser-HTML-Tests-monty.5'.
                ].! !

!ConfigurationOfXMLParserHTML methodsFor: 'versions' stamp: 'monty 1/7/2015 00:33'!
version109: spec 
        <version: '1.0.9' imports: #('1.0.0-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser-HTML-Core' with: 'XML-Parser-HTML-Core-monty.17'.
			spec package: 'XML-Parser-HTML-Tests' with: 'XML-Parser-HTML-Tests-monty.6'.
                ].! !

!ConfigurationOfXMLParserHTML methodsFor: 'versions' stamp: 'monty 1/7/2015 02:42'!
version110: spec 
        <version: '1.1.0' imports: #('1.0.0-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser-HTML-Core' with: 'XML-Parser-HTML-Core-monty.18'.
			spec package: 'XML-Parser-HTML-Tests' with: 'XML-Parser-HTML-Tests-monty.7'.
                ].! !

!ConfigurationOfXMLParserHTML methodsFor: 'versions' stamp: 'monty 3/22/2015 03:01'!
version111: spec 
        <version: '1.1.1' imports: #('1.0.0-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser-HTML-Core' with: 'XML-Parser-HTML-Core-monty.20'.
			spec package: 'XML-Parser-HTML-Tests' with: 'XML-Parser-HTML-Tests-monty.7'.
                ].! !

!ConfigurationOfXMLParserHTML methodsFor: 'versions' stamp: 'monty 3/22/2015 17:41'!
version112: spec 
        <version: '1.1.2' imports: #('1.0.0-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser-HTML-Core' with: 'XML-Parser-HTML-Core-monty.20'.
			spec package: 'XML-Parser-HTML-Tests' with: 'XML-Parser-HTML-Tests-monty.8'.
                ].! !

!ConfigurationOfXMLParserHTML methodsFor: 'versions' stamp: 'monty 3/24/2015 21:02'!
version113: spec 
        <version: '1.1.3' imports: #('1.0.0-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser-HTML-Core' with: 'XML-Parser-HTML-Core-monty.21'.
			spec package: 'XML-Parser-HTML-Tests' with: 'XML-Parser-HTML-Tests-monty.9'.
                ].! !

!ConfigurationOfXMLParserHTML methodsFor: 'versions' stamp: 'monty 4/3/2015 03:21'!
version114: spec 
        <version: '1.1.4' imports: #('1.1.4-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser-HTML-Core' with: 'XML-Parser-HTML-Core-monty.22'.
			spec package: 'XML-Parser-HTML-Tests' with: 'XML-Parser-HTML-Tests-monty.10'.
                ].! !

!ConfigurationOfXMLParserHTML methodsFor: 'versions' stamp: 'monty 4/6/2015 09:42'!
version115: spec 
        <version: '1.1.5' imports: #('1.1.4-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser-HTML-Core' with: 'XML-Parser-HTML-Core-monty.23'.
			spec package: 'XML-Parser-HTML-Tests' with: 'XML-Parser-HTML-Tests-monty.12'.
                ].! !

!ConfigurationOfXMLParserHTML methodsFor: 'versions' stamp: 'monty 4/7/2015 00:39'!
version116: spec 
        <version: '1.1.6' imports: #('1.1.4-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser-HTML-Core' with: 'XML-Parser-HTML-Core-monty.24'.
			spec package: 'XML-Parser-HTML-Tests' with: 'XML-Parser-HTML-Tests-monty.13'.
                ].! !

!ConfigurationOfXMLParserHTML methodsFor: 'versions' stamp: 'monty 4/27/2015 00:30'!
version117: spec 
        <version: '1.1.7' imports: #('1.1.4-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser-HTML-Core' with: 'XML-Parser-HTML-Core-monty.25'.
			spec package: 'XML-Parser-HTML-Tests' with: 'XML-Parser-HTML-Tests-monty.13'.
                ].! !

!ConfigurationOfXMLParserHTML methodsFor: 'versions' stamp: 'monty 5/8/2015 22:52'!
version118: spec 
        <version: '1.1.8' imports: #('1.1.4-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser-HTML-Core' with: 'XML-Parser-HTML-Core-monty.26'.
			spec package: 'XML-Parser-HTML-Tests' with: 'XML-Parser-HTML-Tests-monty.13'.
                ].! !

!ConfigurationOfXMLParserHTML methodsFor: 'versions' stamp: 'monty 5/26/2015 02:21'!
version119: spec 
        <version: '1.1.9' imports: #('1.1.4-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser-HTML-Core' with: 'XML-Parser-HTML-Core-monty.27'.
			spec package: 'XML-Parser-HTML-Tests' with: 'XML-Parser-HTML-Tests-monty.14'.
                ].! !

!ConfigurationOfXMLParserHTML methodsFor: 'versions' stamp: 'monty 5/29/2015 06:37'!
version120: spec 
        <version: '1.2.0' imports: #('1.1.4-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser-HTML-Core' with: 'XML-Parser-HTML-Core-monty.28'.
			spec package: 'XML-Parser-HTML-Tests' with: 'XML-Parser-HTML-Tests-monty.15'.
                ].! !

!ConfigurationOfXMLParserHTML methodsFor: 'versions' stamp: 'monty 6/15/2015 06:07'!
version121: spec 
        <version: '1.2.1' imports: #('1.1.4-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser-HTML-Core' with: 'XML-Parser-HTML-Core-monty.31'.
			spec package: 'XML-Parser-HTML-Tests' with: 'XML-Parser-HTML-Tests-monty.16'.
                ].! !

!ConfigurationOfXMLParserHTML methodsFor: 'versions' stamp: 'monty 12/4/2015 09:34'!
version122: spec 
        <version: '1.2.2' imports: #('1.2.2-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser-HTML-Core' with: 'XML-Parser-HTML-Core-monty.32'.
			spec package: 'XML-Parser-HTML-Tests' with: 'XML-Parser-HTML-Tests-monty.17'.
                ].! !

!ConfigurationOfXMLParserHTML methodsFor: 'versions' stamp: 'monty 2/20/2016 13:28'!
version123: spec 
        <version: '1.2.3' imports: #('1.2.2-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser-HTML-Core' with: 'XML-Parser-HTML-Core-monty.33'.
			spec package: 'XML-Parser-HTML-Tests' with: 'XML-Parser-HTML-Tests-monty.17'.
                ].! !

!ConfigurationOfXMLParserHTML methodsFor: 'versions' stamp: 'monty 3/23/2016 01:52'!
version124: spec 
        <version: '1.2.4' imports: #('1.2.4-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser-HTML-Core' with: 'XML-Parser-HTML-Core-monty.35'.
			spec package: 'XML-Parser-HTML-Tests' with: 'XML-Parser-HTML-Tests-monty.17'.
                ].! !

!ConfigurationOfXMLParserHTML methodsFor: 'versions' stamp: 'monty 3/26/2016 01:37'!
version125: spec 
        <version: '1.2.5' imports: #('1.2.5-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser-HTML-Core' with: 'XML-Parser-HTML-Core-monty.36'.
			spec package: 'XML-Parser-HTML-Tests' with: 'XML-Parser-HTML-Tests-monty.17'.
                ].! !

!ConfigurationOfXMLParserHTML methodsFor: 'versions' stamp: 'monty 4/2/2016 02:35'!
version126: spec 
        <version: '1.2.6' imports: #('1.2.6-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser-HTML-Core' with: 'XML-Parser-HTML-Core-monty.37'.
			spec package: 'XML-Parser-HTML-Tests' with: 'XML-Parser-HTML-Tests-monty.17'.
                ].! !

!ConfigurationOfXMLParserHTML methodsFor: 'versions' stamp: 'monty 4/21/2016 08:31'!
version127: spec 
        <version: '1.2.7' imports: #('1.2.7-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser-HTML-Core' with: 'XML-Parser-HTML-Core-monty.38'.
			spec package: 'XML-Parser-HTML-Tests' with: 'XML-Parser-HTML-Tests-monty.17'.
                ].! !

!ConfigurationOfXMLParserHTML methodsFor: 'versions' stamp: 'monty 7/6/2016 02:53'!
version128: spec 
        <version: '1.2.8' imports: #('1.2.8-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser-HTML-Core' with: 'XML-Parser-HTML-Core-monty.39'.
			spec package: 'XML-Parser-HTML-Tests' with: 'XML-Parser-HTML-Tests-monty.18'.
                ].! !

!ConfigurationOfXMLParserHTML methodsFor: 'versions' stamp: 'monty 9/6/2016 02:31'!
version129: spec 
        <version: '1.2.9' imports: #('1.2.9-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser-HTML-Core' with: 'XML-Parser-HTML-Core-monty.40'.
			spec package: 'XML-Parser-HTML-Tests' with: 'XML-Parser-HTML-Tests-monty.20'.
                ].! !

!ConfigurationOfXMLParserHTML methodsFor: 'versions' stamp: 'monty 9/28/2016 23:34'!
version130: spec 
        <version: '1.3.0' imports: #('1.3.0-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser-HTML-Core' with: 'XML-Parser-HTML-Core-monty.41'.
			spec package: 'XML-Parser-HTML-Tests' with: 'XML-Parser-HTML-Tests-monty.21'.
                ].! !

!ConfigurationOfXMLParserHTML methodsFor: 'versions' stamp: 'monty 10/30/2016 09:47'!
version131: spec 
        <version: '1.3.1' imports: #('1.3.1-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser-HTML-Core' with: 'XML-Parser-HTML-Core-monty.42'.
			spec package: 'XML-Parser-HTML-Tests' with: 'XML-Parser-HTML-Tests-monty.22'.
                ].! !

!ConfigurationOfXMLParserHTML methodsFor: 'versions' stamp: 'monty 11/28/2016 02:52'!
version132: spec 
        <version: '1.3.2' imports: #('1.3.2-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser-HTML-Core' with: 'XML-Parser-HTML-Core-monty.43'.
			spec package: 'XML-Parser-HTML-Tests' with: 'XML-Parser-HTML-Tests-monty.23'.
                ].! !

!ConfigurationOfXMLParserHTML methodsFor: 'versions' stamp: 'monty 3/31/2017 19:03'!
version133: spec 
        <version: '1.3.3' imports: #('1.3.2-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser-HTML-Core' with: 'XML-Parser-HTML-Core-monty.44'.
			spec package: 'XML-Parser-HTML-Tests' with: 'XML-Parser-HTML-Tests-monty.23'.
                ].! !

!ConfigurationOfXMLParserHTML methodsFor: 'versions' stamp: 'monty 4/13/2017 06:17'!
version134: spec 
        <version: '1.3.4' imports: #('1.3.4-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser-HTML-Core' with: 'XML-Parser-HTML-Core-monty.45'.
			spec package: 'XML-Parser-HTML-Tests' with: 'XML-Parser-HTML-Tests-monty.23'.
                ].! !

!ConfigurationOfXMLParserHTML methodsFor: 'versions' stamp: 'monty 5/4/2017 18:14'!
version135: spec 
        <version: '1.3.5' imports: #('1.3.4-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser-HTML-Core' with: 'XML-Parser-HTML-Core-monty.46'.
			spec package: 'XML-Parser-HTML-Tests' with: 'XML-Parser-HTML-Tests-monty.24'.
                ].! !

!ConfigurationOfXMLParserHTML methodsFor: 'versions' stamp: 'monty 5/20/2017 03:36'!
version136: spec 
        <version: '1.3.6' imports: #('1.3.6-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser-HTML-Core' with: 'XML-Parser-HTML-Core-monty.47'.
			spec package: 'XML-Parser-HTML-Tests' with: 'XML-Parser-HTML-Tests-monty.24'.
                ].! !

!ConfigurationOfXMLParserHTML methodsFor: 'versions' stamp: 'monty 6/5/2017 17:03'!
version137: spec 
        <version: '1.3.7' imports: #('1.3.6-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser-HTML-Core' with: 'XML-Parser-HTML-Core-monty.48'.
			spec package: 'XML-Parser-HTML-Tests' with: 'XML-Parser-HTML-Tests-monty.24'.
                ].! !

!ConfigurationOfXMLParserHTML methodsFor: 'versions' stamp: 'monty 8/31/2017 07:38'!
version138: spec 
        <version: '1.3.8' imports: #('1.3.8-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser-HTML-Core' with: 'XML-Parser-HTML-Core-monty.49'.
			spec package: 'XML-Parser-HTML-Tests' with: 'XML-Parser-HTML-Tests-monty.25'.
                ].! !

!ConfigurationOfXMLParserHTML methodsFor: 'versions' stamp: 'monty 10/8/2017 23:30'!
version139: spec 
        <version: '1.3.9' imports: #('1.3.9-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser-HTML-Core' with: 'XML-Parser-HTML-Core-monty.50'.
			spec package: 'XML-Parser-HTML-Tests' with: 'XML-Parser-HTML-Tests-monty.25'.
                ].! !

!ConfigurationOfXMLParserHTML methodsFor: 'versions' stamp: 'monty 10/17/2017 01:53'!
version140: spec 
        <version: '1.4.0' imports: #('1.3.9-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser-HTML-Core' with: 'XML-Parser-HTML-Core-monty.51'.
			spec package: 'XML-Parser-HTML-Tests' with: 'XML-Parser-HTML-Tests-monty.25'.
                ].! !

!ConfigurationOfXMLParserHTML methodsFor: 'versions' stamp: 'monty 1/23/2018 08:09'!
version141: spec 
        <version: '1.4.1' imports: #('1.4.1-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser-HTML-Core' with: 'XML-Parser-HTML-Core-monty.52'.
			spec package: 'XML-Parser-HTML-Tests' with: 'XML-Parser-HTML-Tests-monty.25'.
                ].! !
